<?php
/**
 *   oai2.admin.inc
 *
 *   Copyright (C) 2006 -2012  Ron Jerome
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License along
 *   with this program; if not, write to the Free Software Foundation, Inc.,
 *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 */

function oai2_admin_settings() {
  $form = array();

  $base_url = $GLOBALS['base_url'];

  //------------ Group 1: Global Configuration
  $form['oai2_configuration'] = array(
      '#type' => 'fieldset',
      '#title' => t('Configuration'),
      '#collapsible' => TRUE,
      '#collapsed' => FALSE
  );
  $form['oai2_configuration']['oai_repository_name'] = array(
      '#type' => 'textfield',
      '#title' => t('Repository Name'),
      '#required' => TRUE,
      '#size' => '50',
      '#default_value' =>  variable_get('oai_repository_name', variable_get('site_name', 'Biblio OAI'))
  );
  $form['oai2_configuration']['oai_path'] = array(
      '#type' => 'textfield',
      '#title' => t('The path of the Repository'),
      '#field_prefix' => $base_url . '/',
      '#required' => TRUE,
      '#size' => '50',
      '#default_value' => variable_get('oai_path', 'oai'),
      '#description' => 'The path where the OAI-PMH service respond. Es. '. $base_url .'/oai'
  );

  $form['oai2_configuration']['oai_repository_identifier'] = array(
      '#type' => 'textfield',
      '#title' => t('Repository unique identifier'),
      '#required' => TRUE,
      '#size' => '50',
      '#default_value' => variable_get('oai_repository_identifier', 'oai:' . variable_get('site_name', 'Biblio OAI')),
      '#description' => 'The identifier for this repository. Eg. oai:<strong>drupal-site.org</strong>:123.',
  );
  $form['oai2_configuration']['oai_admin_email'] = array(
      '#type' => 'textfield',
      '#title' => t('Admin Email'),
      '#size' => '50',
      '#default_value' => variable_get('oai_admin_email', variable_get('site_mail', ini_get('sendmail_from')))
  );
  $form['oai2_configuration']['oai_max_size'] = array(
      '#type' => 'textfield',
      '#title' => t('Maximum Response Size'),
      '#size' => '50',
      '#default_value' => variable_get('oai_max_size', '20'),
      '#description' => 'The maximum number of records to issue per response. If result set is larger than this number,
                        a resumption token will be issued',
  );
  $form['oai2_configuration']['oai_expire_time'] = array(
      '#type' => 'textfield',
      '#title' => t('Expiration Time'),
      '#size' => '50',
      '#default_value' => variable_get('oai_expire_time', '86400'),
      '#description' => 'The amount of time a resumption token will remain valid in seconds. Defaults to one day (86400s).',
  );
  $form['oai2_configuration']['oai_deleted_records'] = array(
      '#type' => 'checkbox',
      '#title' => t('Track and report deleted records'),
      '#size' => '50',
      '#default_value' => variable_get('oai_deleted_records', TRUE),
      '#description' => 'Track deleted records and report them to the harvesters.',
  );
/*
 *
   $form['oai2_configuration']['oai_compression'] = array(
        '#type' => 'checkbox',
        '#title' => t('Output Compression'),
        '#size' => '50',
        '#default_value' => variable_get('oai_compression', '1'),
        '#description' => 'Compress the OAI output stream.',
  );
*/
  $vocabs = oai2_admin_get_taxonomy_set_options();

  if (count($vocabs)) {
    $form['oai2_terms'] = array(
        '#type'  => 'fieldset',
        '#title' => t('OAI "sets" using taxonomy terms'),
        '#description' => t('Select terms from the vocabularies below.  A new set will be created for each term selected.')
    );
    foreach ($vocabs as $name => $options) {
      asort($options);
      $name = str_replace(' ', '_', $name);
      $form['oai2_terms']['oai2_term_set_' . $name] = array(
          '#type' => 'select',
          '#title' => 'Vocabulary ' . $name,
          '#default_value' => variable_get('oai2_term_set_' . $name, ''),
          '#options' => $options,
          '#multiple' => TRUE,
          '#size' =>  min(6, count($options)) ,
      );
    }
  }

  return system_settings_form($form);
}

function oai2_admin_get_schema($name) {
  //$headers = 'Content-type: application/xml; charset=utf-8';
  $metadata = db_fetch_object(db_query("SELECT * FROM {oai2_metadata_schemas} WHERE name='%s' ",$name));
  if (isset($metadata->oai_schema)) {
    global $base_url;
    $xsd = str_replace('__LOCAL__', $base_url . '/oai/schema/', $metadata->oai_schema);
    drupal_set_header('Content-type: text/xml; charset=utf-8');
    print $xsd;
  }
}
function oai2_admin_metadata_form($form_state) {

}

function theme_oai2_admin_metadata_form($form) {

}
function oai2_admin_metadata_form_validate($form, $form_state) {

}

function oai2_admin_metadata_form_submit($form, $form_state) {

}

function oai2_admin_get_taxonomy_set_options() {
  global $db_type;
  $options = array();

  $vocabs = taxonomy_get_vocabularies('biblio');

  foreach ($vocabs as $vocab) {
    $key = str_replace(' ', '_', $vocab->name);
    $terms = taxonomy_get_tree($vocab->vid);
    foreach ($terms as $term) {
      $options[$key][$term->tid] = $term->name;
    }
  }

  // clean up any existing invalid entries

  $match_op = ($db_type == 'pgsql') ? '~*' : 'LIKE';
  $query = 'SELECT * FROM {variable} WHERE name ' . $match_op . "'oai2_term_set_'" ;
  $result = db_query($query);

  while ($row = db_fetch_object($result)) {
    $vocab_name = str_replace('oai2_term_set_', '', $row->name);
    if (!array_key_exists($vocab_name, $options)) {
      variable_del($row->name);
    }
  }

  return $options;
}